@@ -1,6 +1,8 @@
-# Copyright 2010 Jacob Kaplan-Moss
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
+# Copyright 2010 Jacob Kaplan-Moss
 # Copyright 2012 OpenStack Foundation
+# Copyright 2013 Rackspace Hosting
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -108,7 +110,7 @@ class Manager(utils.HookableMixin):
         cache_dir = os.path.expanduser(os.path.join(base_dir, uniqifier))
 
         try:
-            os.makedirs(cache_dir, 0755)
+            os.makedirs(cache_dir, 0o755)
         except OSError:
             # NOTE(kiall): This is typicaly either permission denied while
             #              attempting to create the directory, or the directory
