@@ -1,3 +1,22 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack Foundation
+# Copyright 2013 Rackspace Hosting
+# Copyright 2013 Hewlett-Packard Development Company, L.P.
+# All Rights Reserved.
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 from testtools import TestCase
 from mock import Mock
 
@@ -15,16 +34,16 @@ class CommonTest(TestCase):
                               common.check_for_exceptions, resp, "body")
 
     def test_limit_url(self):
-        url_ = "test-url"
-        limit_ = None
-        marker_ = None
-        self.assertEqual(url_, common.limit_url(url_))
+        url = "test-url"
+        limit = None
+        marker = None
+        self.assertEqual(url, common.limit_url(url))
 
-        limit_ = "test-limit"
-        marker_ = "test-marker"
+        limit = "test-limit"
+        marker = "test-marker"
         expected = "test-url?marker=test-marker&limit=test-limit"
         self.assertEqual(expected,
-                         common.limit_url(url_, limit=limit_, marker=marker_))
+                         common.limit_url(url, limit=limit, marker=marker))
 
 
 class PaginatedTest(TestCase):
@@ -51,10 +70,10 @@ class PaginatedTest(TestCase):
     def test___iter__(self):
         itr_expected = self.items_.__iter__()
         itr = self.pgn.__iter__()
-        self.assertEqual(itr_expected.next(), itr.next())
-        self.assertEqual(itr_expected.next(), itr.next())
-        self.assertRaises(StopIteration, itr_expected.next)
-        self.assertRaises(StopIteration, itr.next)
+        self.assertEqual(next(itr_expected), next(itr))
+        self.assertEqual(next(itr_expected), next(itr))
+        self.assertRaises(StopIteration, next, itr_expected)
+        self.assertRaises(StopIteration, next, itr)
 
     def test___getitem__(self):
         self.assertEqual(self.items_[0], self.pgn.__getitem__(0))
@@ -70,9 +89,9 @@ class PaginatedTest(TestCase):
     def test___reversed__(self):
         itr = self.pgn.__reversed__()
         expected = ["item2", "item1"]
-        self.assertEqual("item2", itr.next())
-        self.assertEqual("item1", itr.next())
-        self.assertRaises(StopIteration, itr.next)
+        self.assertEqual("item2", next(itr))
+        self.assertEqual("item1", next(itr))
+        self.assertRaises(StopIteration, next, itr)
 
     def test___contains__(self):
         self.assertTrue(self.pgn.__contains__("item1"))
