@@ -1,3 +1,22 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack Foundation
+# Copyright 2013 Rackspace Hosting
+# Copyright 2013 Hewlett-Packard Development Company, L.P.
+# All Rights Reserved.
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 from testtools import TestCase
 from mock import Mock
 
@@ -98,10 +117,10 @@ class InstancesTest(TestCase):
             return path, inst, limit, marker
 
         self.instances._list = Mock(side_effect=side_effect_func)
-        limit_ = "test-limit"
-        marker_ = "test-marker"
-        expected = ("/instances", "instances", limit_, marker_)
-        self.assertEqual(expected, self.instances.list(limit_, marker_))
+        limit = "test-limit"
+        marker = "test-marker"
+        expected = ("/instances", "instances", limit, marker)
+        self.assertEqual(expected, self.instances.list(limit, marker))
 
     def test_get(self):
         def side_effect_func(path, inst):
