@@ -1,4 +1,8 @@
-# Copyright (c) 2013 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack Foundation
+# Copyright 2013 Rackspace Hosting
+# Copyright 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,7 +18,7 @@
 #    under the License.
 
 from troveclient import base
-import exceptions
+from troveclient.openstack.common.apiclient import exceptions
 
 
 class Limit(base.Resource):
