@@ -1,12 +1,26 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack Foundation
+# Copyright 2013 Rackspace Hosting
+# All Rights Reserved.
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 from __future__ import print_function
 
-import argparse
-import copy
-import os
 import sys
 import time
 
-from troveclient import exceptions
 from troveclient import utils
 
 
@@ -399,7 +413,7 @@ def do_user_update_attributes(cs, args):
            nargs="+", default=[])
 @utils.service_type('database')
 def do_user_grant_access(cs, args):
-    """Grants access to a atabase(s) for a user."""
+    """Grants access to a database(s) for a user."""
     cs.users.grant(args.instance, args.name,
                    args.databases, hostname=args.host)
 
@@ -450,7 +464,7 @@ def do_root_show(cs, args):
 
 @utils.service_type('database')
 def do_secgroup_list(cs, args):
-    """Lists all security gropus."""
+    """Lists all security groups."""
     wrapper = cs.security_groups.list()
     sec_grps = wrapper.items
     while (wrapper.next):
